import logging
import os
from abc import ABC, abstractmethod
from datetime import datetime

DEBUG_BASE_URL = os.environ.get('LQ_NOTIFIER_BASE_URL', 'http://localhost:8900')
TIMESTAMP_FORMAT = '%-I:%M:%S%p GMT, %b %d, %Y'
LOG_LEVEL = os.environ.get('log_level', 'info').upper()
logger = logging.getLogger()
logger.setLevel(logging.getLevelName(LOG_LEVEL))


class BaseNotifier(ABC):
    def __init__(self, url_mappings, wavefront_registry, telegraf_client):
        self.wavefront_registry = wavefront_registry
        self.url_mappings = url_mappings
        self.telegraf_client = telegraf_client

    @abstractmethod
    def send(self, event):
        pass

    def format_timestamp(self, value):
        t = datetime.utcfromtimestamp(value)
        return t.strftime(TIMESTAMP_FORMAT).replace('AM', 'am').replace('PM', 'pm')

    def get_base_url_for_env(self, cbd_env: str, external_ingress_hostname: str):
        cbd_env = cbd_env.lower()

        # all prod mappings explicitly defined
        base_url = self.url_mappings.get(cbd_env, None)
        if base_url:
            return base_url
        elif external_ingress_hostname:
            return external_ingress_hostname

        # local env only supported if lambda is also running in local mode
        if self.env == 'local' and cbd_env == 'local':
            return DEBUG_BASE_URL

        raise ValueError('Unsupported environment: {env}'.format(env=cbd_env))

    def wavefront_counter(self, counter_name):
        try:
            self.wavefront_registry.counter(counter_name).inc()
            logger.info('Sent wavefront metrics for %s count of 1', counter_name)
        except Exception as we:
            logger.exception("Failed to send metrics to wavefront.")
